from typing import List

from .fib_number import recurring_fibonacci_number


def calculate_numbers(numbers: List[int]) -> List[int]:
    """
    Calculates a range of Fibonacci numbers from a list.

    :param numbers: (List[int]) the Fibonacci numbers to be calculated
    :return: (List[int]) the calculated Fibonacci numbers
    """
    return [recurring_fibonacci_number(number=i) for i in numbers]



from unittest import main, TestCase

from flitton_fib_py.fib_calcs.fib_number \
    import recurring_fibonacci_number


class RecurringFibNumberTest(TestCase):

    def test_zero(self):
        self.assertEqual(
            0, recurring_fibonacci_number(number=0)
        )

    def test_negative(self):
        with self.assertRaises(ValueError) as raised_error:
            recurring_fibonacci_number(number=-1)
        self.assertEqual(
            "Fibonacci has to be equal or above zero",
            str(raised_error.exception)
        )

    def test_one(self):
        self.assertEqual(
            1, recurring_fibonacci_number(number=1)
        )

    def test_two(self):
        self.assertEqual(
            1, recurring_fibonacci_number(number=2)
        )

    def test_twenty(self):
        self.assertEqual(
            6765, recurring_fibonacci_number(number=20)
        )


if __name__ == "__main__":
    main()



import argparse

from flitton_fib_py.fib_calcs.fib_number \
    import recurring_fibonacci_number


def fib_numb() -> None:
    parser = argparse.ArgumentParser(
        description='Calculate Fibonacci numbers')
    parser.add_argument('--number', action='store',
                        type=int, required=True,
                        help="Fibonacci number to be calculated")
    args = parser.parse_args()
    print(f"Your Fibonacci number is: "
          f"{recurring_fibonacci_number(number=args.number)}")



# forcing a build


def recurring_fibonacci_number(number: int) -> int:
    """
    Calculates the fibonacci number needed.

    :param number: (int) the Fibonacci number to be calculated
    :return: (Optional[int]) the calculated fibonacci number
    """
    if number < 0:
        raise ValueError("Fibonacci has to be equal or above zero")
    elif number <= 1:
        return number
    else:
        return recurring_fibonacci_number(number - 1) + \
               recurring_fibonacci_number(number - 2)



import pathlib

from setuptools import find_packages, setup


with open("README.md", "r") as fh:
    long_description = fh.read()


with open(str(pathlib.Path(__file__).parent.absolute()) +
          "/flitton_fib_py/version.py", "r") as fh:
    version = fh.read().split("=")[1].replace("'", "")


setup(
    name="flitton_fib_py",
    version=version,
    author="Maxwell Flitton",
    author_email="maxwell@gmail.com",
    description="Calculates a Fibonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/maxwellflitton/flitton-fib-py",
    install_requires=[
        "PyYAML>=4.1.2",
        "dill>=0.2.8"
    ],
    extras_require={
     'server': ["Flask>=1.0.0"]
    },
    packages=find_packages(exclude=("tests",)),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'fib-number = flitton_fib_py.cmd.fib_numb:fib_numb',
        ],
    },
    python_requires='>=3',
    tests_require=['pytest'],
)
